/***************************************************************************/
/*                                                                         */
/*       #####   #####  #     #       #  #####   #####    ###              */
/*      #     # #     # ##    #      #  #     # #     #    #               */
/*      #       #       # #   #     #   #       #          #               */
/*      #       #       #  #  #    #    #        #####     #               */
/*      #       #       #   # #   #     #             #    #               */
/*      #     # #     # #    ##  #      #     # #     #    #               */
/*       #####   #####  #     # #        #####   #####    ###              */
/*                                                                         */
/*****************************************************************************/
/*
* @PROJECT  CCN/CSI
* @SYSTEM   APACHE
* @PACKAGE  MONMGMT 
*
* @FILE     monitor.lex
*
* @AUTHOR   Stephane STEINIER
*
* @ABSTRACT
* Apache MONitoring ManaGeMenT (MONMGMT) : LEX file
*
* This file contains:
* the LEX directive to parse the Big Brother files
*
* @INCLUDE
*
*/
/*
* HISTORY
* ----------|-------|--------------------------------------------------------
*    Date   | Patch | Author & Description
* ----------|-------|--------------------------------------------------------
* 31-Oct-03 |OR05972| SST - Creation
* ----------|-------|--------------------------------------------------------
* 26-Nov-03 |OR06010| SST - Uniformisation of the error messages
* ----------|-------|--------------------------------------------------------
* 02-Mar-04 |OR06144| SST - RFA-112 implementation (https statistics)
* ----------|-------|--------------------------------------------------------
* 13-May-05 |OR06755| FER - RFA-160 implementation (ns50 monitoring)
* ----------|-------|--------------------------------------------------------
* 01-Jul-05 |  6740 | VVA - RFA-150 : Portage CCN/CSI sur Linux RedHAT3
* ----------|-------|--------------------------------------------------------
* 04-Apr-06 |OR07163| FER - add parsing for new alert messages for T34app
* ----------|-------|--------------------------------------------------------
* 25-Jun-09 |OR10939| CLO - Review the whole parser
* ----------|-------|--------------------------------------------------------
* 04-Jan-10 |OR10575| CLO - Integrate Fwl/Ns50 in main monitoring
* ----------|-------|--------------------------------------------------------
*/

%{

#include <stdio.h>
#include <string.h>

#include "y.tab.h"

#include "gcn_uptyp.h"
#include "gcn_upcon.h"

#include "monitor_prcon.h"

extern YYSTYPE yylval;

extern CSILONG iTask;
extern CSIBOOLEAN NewFile;


#define YY_DECL int yylex ( void )
YY_DECL;

%}

%p10000
%a7000
%n1500
%s FIRST_LINE ALERT_TEXT ALERT_COLOR ALERT_OBJECT

colour      ([Gg]reen|[Yy]ellow|[Rr]ed|[Pp]urple)
object      [^ \t\n]+[^: \t\n]
date        [0-9]{2}"/"[0-9]{2}"/"[0-9]{4}
time        [012][0-9]:[0-5][0-9]:[0-5][0-9]
message     [^ \t\n]*[^\n]+
keywords    (LDAP" "+[eE]rror|[pP]rotocol|[fF]ile|[cC]annot|[uU]nknown|[eE]rror|[sS]yntax|No" "+[rR]eport|[nN]ot" "+[fF]ound)
error       [^ \t\n]*{keywords}[^\n]*

%%

[ \t]	;

<INITIAL,ALERT_COLOR>{colour} {
    if (CSITRUE == NewFile)
    {
        NewFile = CSIFALSE;
        BEGIN (FIRST_LINE);
    }
    else
    {
        switch (iTask)                
        {
            /* We can customize the alert patern by task if needed */
            case RR :
            case ASYNC :
            case HTTP :
            case HTTPS :
            case APP :                
            case QUE :                
            case USR :                
            case NS50 :
               BEGIN (ALERT_OBJECT);
        }
    }
    yylval.string = strdup(yytext);
    return ALERT;
}

<FIRST_LINE>{date} {
    yylval.string = strdup(yytext);
    return DATE;
}

<FIRST_LINE>{time} {
    yylval.string = strdup(yytext);
    BEGIN (ALERT_COLOR);
    return TIME;
}

<ALERT_OBJECT>{object} {
    yylval.string = strdup(yytext);
    BEGIN (ALERT_TEXT);
    return OBJECT;
}

<ALERT_OBJECT>{error} {
    yylval.string = strdup(yytext);
    BEGIN (ALERT_COLOR);
    return ERROR;
}

<ALERT_TEXT>{message} {
    /* The message is not an empty string:  */
    /* colour object message                */
    yylval.string = strdup(yytext);
    BEGIN (ALERT_COLOR);
    return MESSAGE;
}

<ALERT_TEXT>""/\n {
    /* The message is an empty string:  */
    /* colour object                    */
    yylval.string = strdup(yytext);
    BEGIN (ALERT_COLOR);
    return MESSAGE;
}

\n  ;

.   ;

%%

