/****************************************************************************

         #####   #####  #     #       #  #####   #####    ###
        #     # #     # ##    #      #  #     # #     #    #
        #       #       # #   #     #   #       #          #
        #       #       #  #  #    #    #        #####     #
        #       #       #   # #   #     #             #    #
        #     # #     # #    ##  #      #     # #     #    #
         #####   #####  #     # #        #####   #####    ###

****************************************************************************/
/*
* @PROJECT  CCN/CSI
* @SYSTEM   CCN
* @PACKAGE  LI (Local Intelligence engine)
*
* @FILE     li_prcon.h
*
* @ABSTRACT
* Local Intelligence PRivate CONstants.
* This file contains:
* - the definitions of the constants used internally by the LI.
*

#ifndef _LI_PRCON_H
#define _LI_PRCON_H

/*
* @MACRODEF GATEWAY_CODEPAGE
*/
#define GATEWAY_CODEPAGE 1L

/*
* @MACRODEF GATEWAY_HOSTFORMAT
*/
#ifdef _LINUX_
#define GATEWAY_HOSTFORMAT           \
"0111000000000000000000000000000"    \
"4401101101100000002202204404400"    \
"0000000000000000000000000000000"    \
"0000000000000000000000000000000000"
#else /* _LINUX_ */
#ifdef _AIX_
#define GATEWAY_HOSTFORMAT \
"0112010000000000000000000000000"    \
"4401101101100000002202204404400"    \
"0000000000000000000000000000000"    \
"0000000000000000000000000000000000"
#else /* _AIX_ */
#error "The GATEWAY_HOSTFORMAT variable is not defined."
#endif /* _AIX_ */
#endif /* _LINUX_ */

/**********************************************************/
/*** EXCHANGE MODE CONSTANTS (SYNCHRONOUS/ASYNCHRONOUS) ***/
/**********************************************************/

/*
* @MACRODEF LI_DEFAULT_FLAGS
* This is the default value for all LI interface flags.
* Current value = 0x00000000L
*/
#define LI_DEFAULT_FLAGS     0x00000000L

/******************************************/
/*** MISCELLANEOUS CONSTANT DEFINITIONS ***/
/******************************************/

/*
* @MACRODEF LI_WORK_BUF_SIZE
* The size of the work buffer of the LI engine (this work buffer is
* used to extract information from the header of a message and to
* compose the new header of the output message).
* Current value = 1024
*/
#define LI_WORK_BUF_SIZE     1024

/**********************************/
/*** OPERATION DISPATCHER FLAGS ***/
/**********************************/

/* Message Routing Yes|No  */
#define LI_ROUTING     0x00000000L
#define LI_NO_ROUTING  0x00000001L

/* Access Control Management Yes|No */
#define LI_ACM         0x00000000L
#define LI_NO_ACM      0x00000002L

/* Message Conversion Yes|No */
#define LI_MSGCONV     0x00000000L
#define LI_NO_MSGCONV  0x00000004L

/* VAS Execution Yes|No */
#define LI_VAS         0x00000000L
#define LI_NO_VAS      0x00000008L

/**************************************/
/*** CONTEXT REQUEST OR REPLY FLAGS ***/
/**************************************/

#define LI_REQUEST     1L
#define LI_REPLY      -1L

#define LI_UNICODE    0x0000L

/*********************************************************************/
/*** SUB-DIRECTORY FOR THE TEMPORARY FILES (FOR REPORTS WITH DATA) ***/
/*********************************************************************/

/*
* @MACRODEF LI_WKPATH
* The name of the subdirectory for the temporary files (reports with
* data).
* Current value = /ccnwkd/tmp/li
*/
#define LI_WKPATH      "/ccnwkd/tmp/li"

/********************************************************************/
/*** NUMBER OF RETRYS WHEN CALL OR CONNECT TO A RAP FAILS BECAUSE ***/
/*** THE REMOTE APPLICATION WAS ABNORMALLY TERMINATED.            ***/
/*** Rem: used by functions li_call() and li_connect(), see files ***/
/*** ---- li_synch.c and li_cvsvc.c                               ***/
/********************************************************************/

/*
* @MACRODEF LI_NB_OF_RETRYS
* The number of retrys of the LI when calling a RAP in
* <@LOCALFUN li_call>.
* Current value = 3
*/
#define LI_NB_OF_RETRYS     3L

/****************************************************/
/*** DEFAULT EXPIRATION VALUE (FOR DEGRADED MODE) ***/
/****************************************************/
/*
* @MACRODEF LI_DEFAULT_EXPIRY_VALUE
* Default expiry time in second.
* Current value = 3600 (1 hours)
*/
#define LI_DEFAULT_EXPIRY_VALUE  3600L

/****************************************************/
/*** CCN PROTOCOL VERSION                         ***/
/****************************************************/
/*
* @MACRODEF  LI_PROTOCOL_VERSION_1
* CCN Protocol version number 1
* Current value = 1
*/
#define LI_PROTOCOL_VERSION_1 1L

/*
* @MACRODEF  LI_PROTOCOL_VERSION_2
* CCN Protocol version number 2
* Current value = 2
*/
#define LI_PROTOCOL_VERSION_2 2L

/*
* @MACRODEF  LI_PROTOCOL_VERSION_3
* CCN Protocol version number 3
* Current value = 3
*/
#define LI_PROTOCOL_VERSION_3 3L

/*
* @MACRODEF  LI_PROTOCOL_VERSION
* Current CCN Protocol version
* Current value = LI_PROTOCOL_VERSION_3
*/
#define LI_PROTOCOL_VERSION LI_PROTOCOL_VERSION_3

/****************************************************/
/*** LAST VERSION WORKING WITH TRANFER AGENT      ***/
/****************************************************/
/*
* @MACRODEF  LI_LAST_VERSION_WITH_TA
* CCN Protocol version number working with Transfer Agent.
* Current value = LI_PROTOCOL_VERSION_1
*/
#define  LI_LAST_VERSION_WITH_TA  LI_PROTOCOL_VERSION_1

/**********************************************************/
/*** CONSTANTS NEEDED TO MQINQ THE ALI QUEUE IN SVRINIT ***/
/**********************************************************/
/*
* @MACRODEF ALI_MQINQ_REQUESTED_ATTR_MXNUM
* Defines the number of attributes requested to the MQINQ call.
*/
#define ALI_MQINQ_REQUESTED_ATTR_MXNUM 2

/*
* @MACRODEF ALI_MQINQ_REQUESTED_INT_ATTR_MXNUM
* Defines the number of attributes of type integer requested to the MQINQ call.
*/
#define ALI_MQINQ_REQUESTED_INT_ATTR_MXNUM 1

/*
* @MACRODEF ALI_MQINQ_QUEUE_DEPTH_ATTR_INDEX
* Defines the index of the current depth attribute in the array of the
* attribute selectors
*/
#define ALI_MQINQ_QUEUE_DEPTH_ATTR_INDEX 0

/*
* @MACRODEF ALI_MQINQ_TRIGGER_DATA_ATTR_INDEX
* Defines the index of the trigger data attribute in the array of the
* attribute selectors
*/
#define ALI_MQINQ_TRIGGER_DATA_ATTR_INDEX 1

/*
* @MACRODEF ALI_MQSET_REQUESTED_INT_ATTR_MXNUM
* Defines the number of attributes of type integer requested to the MQSET call.
*/
#define ALI_MQSET_REQUESTED_ATTR_MXNUM    1     /* Number of requested attrs. */
                                                /* for an MQ set call         */

/*
* @MACRODEF ALI_MQSET_QUEUE_DEPTH_ATTR_INDEX
* Defines the index of the trigger type  attribute in the array of the
* attribute selectors
*/
#define ALI_MQSET_TRIGTYPE_ATTR_INDEX     0     /* Index for the 'trigger     */
                                                /* type' attribute            */


/*
* @MACRODEF ALI_MESSAGES_MXNUM
* Defines the maximum number of messages one ALI process can handle after
* its initialisation phase.
*/
#define ALI_MESSAGES_MXNUM 5

#endif /* _LI_PRCON_H */
/****************************************************************************/
