/****************************************************************************

         #####   #####  #     #       #  #####   #####    ###
        #     # #     # ##    #      #  #     # #     #    #
        #       #       # #   #     #   #       #          #
        #       #       #  #  #    #    #        #####     #
        #       #       #   # #   #     #             #    #
        #     # #     # #    ##  #      #     # #     #    #
         #####   #####  #     # #        #####   #####    ###

****************************************************************************/
/*
* @PROJECT  CCN/CSI
* @SYSTEM   CCN
* @PACKAGE  LI (Local Intelligence engine)
* 
* @FILE     li_prtyp.h
* 
* @ABSTRACT
* Local Intelligence PRivate TYPe definitions.
* This file contains:
* - the type definitions for the Local Intelligence Engine;
* 
*/

#ifndef _LI_PRTYP_H
#define _LI_PRTYP_H

/************************************************/
/*** LI PROCESS CONTEXT STRUCTURE DEFINITIONS ***/
/************************************************/

/*
* @MACRODEF LI_PROCCONTEXT_STRUC_ID
* LI_PROCCONTEXT Structure Identifier
*/

#define LI_PROCCONTEXT_STRUC_ID          "LIP"

/*
* @MACRODEF LI_PROCCONTEXT_STRUC_ID_ARRAY
* LI_PROCCONTEXT Structure Identifier (array form)
*/

#define LI_PROCCONTEXT_STRUC_ID_ARRAY    'L','I','P','\0'

/*
* @MACRODEF LI_PROCCONTEXT_VERSION
* LI_PROCCONTEXT Version number
*/

#define LI_PROCCONTEXT_VERSION           1L

/*
* @TYPE LI_PROCCONTEXT
* This is the type of the LI process context. This context contains data
* concerning the LI process as a whole, and not specifically the current 
* processed message.
* 
* @FIELD 
* CSICHAR4      StrucId
*    Structure Identifier
*
* CSILONG       Version
*    Version number
*
* CSICHAR48     Name
*    The application name associated with the LI process (CSI relative name)
*
* CSICHAR48     SvcName
*    The name of the LI service (CSI relative name)
*
* CSILONG       DegrExpTime
*    The expiration delay of a degraded-mode message, in SECONDS.
*
* CSICHAR48     QMgrName
*    The name of the local queue manager (CSI relative name). This parameter can
*    be omitted most of the times, as a CSI_mq_conn with no queue manager name 
*    connects to the default local queue manager.
*
* CSICHAR256    GatewayName
*    The name of the local gateway (Distinguished Name).
*
* CSIHCONN      QMgrHandle
*    The handle of the local queue manager (obtained after the CSI_mq_conn)
*
* CSILONG       ErrNo
*    Last error code returned by the LI process.
*
* @SEEALSO
* <@TYPE LI_MSGCONTEXT>
*/
typedef struct tagLI_PROCCONTEXT {
    CSICHAR4      StrucId;
    CSILONG       Version;
    CSICHAR48     Name;
    CSICHAR48     SvcName;
    CSILONG       DegrExpTime;
    CSICHAR48     QMgrName;
    CSICHAR256    GatewayName;
    CSIHCONN      QMgrHandle;
    CSILONG       ErrNo;
} LI_PROCCONTEXT;

/*
* @MACRODEF LI_PROCCONTEXT_DEFAULT
* Default (initializer) LI_PROCCONTEXT structure
*/
#define LI_PROCCONTEXT_DEFAULT {LI_PROCCONTEXT_STRUC_ID_ARRAY}, \
                               LI_PROCCONTEXT_VERSION, \
                               {""}, \
                               {""}, \
                               LI_DEFAULT_EXPIRY_VALUE, \
                               {""}, \
                               {""}, \
                               CSIMQHC_UNUSABLE_HCONN, \
                               0L

/**************************************/
/*** LI MESSAGE CONTEXT DEFINITIONS ***/
/**************************************/

/*
* @MACRODEF LI_MSGCONTEXT_STRUC_ID
* LI_MSGCONTEXT Structure Identifier
*/
#define LI_MSGCONTEXT_STRUC_ID          "LIM"

/*
* @MACRODEF LI_MSGCONTEXT_STRUC_ID_ARRAY
* LI_MSGCONTEXT Structure Identifier (array form)
*/
#define LI_MSGCONTEXT_STRUC_ID_ARRAY    'L','I','M','\0'

/*
* @MACRODEF LI_MSGCONTEXT_VERSION
* LI_MSGCONTEXT Version number
*/
#define LI_MSGCONTEXT_VERSION           1L

/*
* @TYPE LI_MSGCONTEXT
* This is the LI current message context. It contains information specifically
* concerning the current processed message.
*
* @FIELD 
* CSICHAR4     StrucId
*    The LI_MSGCONTEXT structure identifier.
*
* CSILONG      Version
*    The LI_MSGCONTEXT structure version.
*
* CSILONG      EventType
*    Indicates the origin of the "event" (at this step, it might be a call
*    from the trigger monitor and not an actual message). The possible values
*    for this field are CSI_TRIGGER_EVENT, CSI_LOCAL_EVENT, CSI_REMOTE_EVENT.
*
* CSILONG      ExchangeMode
*    Indicates if the message is synchronous or asynchronous (CSI_SYNCHRON, 
*    CSI_ASYNCHRON value).
*
* CSIIITFHDR  *TraceInfo_P
*    The CSIIITFHDR structure (Trace Information structure) of the message,
*    if EventType equals CSI_LOCAL_EVENT or CSI_REMOTE_EVENT.
*
* CSICHAR48    TriggerQName
*    The name of the Trigger Queue if EventType equals CSI_TRIGGER_EVENT.
*
* CSIQOS      *QoS_P
*    Pointer to the message Quality of Service structure.
*
* CSICHAR     *UserProfileList_P
*    Pointer to the buffer containing the list of user profiles.
*
* CSICHAR     *PrevGatewayList_P
*    Pointer to the buffer containing the list of previous gateways names
*
* CSICHAR256   OrigGateway
*    The Distinguished Name of the Originator gateway.
*
* CSICHAR256   DestGateway
*    The name of the destination gateway (Distinguished Name).
*
* CSICHAR48    NextHopName
*    The name of the next local destination (service|queue) (CSI relative name)
*
* CSILONG      SvcFlags
*    The service flags (in case of a synchronous message).
*
* CSIMQMD      *MsgDesc_P
*    The Message Descriptor (MQ) of the message, if asynchronous.
*
* CSILONG      ClientCodePage
*    The Code Page of the Client Application.
*
* CSICHAR128   ClientHostFormat
*    The Host Format of the Client Application.
*
* CSILONG      ServerCodePage
*    The Code Page of the Server Application.
* 
* CSICHAR128   ServerHostFormat
*    The Host Format of the Server Application.
*
* CSILONG      Direction
*    Indicates whether the message transits from Client to Server (LI_REQUEST),
*    or from Server to Client (LI_REPLY).
*
* CSILONG      XferMemory
*    Indicates whether the message is tranfered by memory and not by file      
*    It is the case if the DestGateway is remote  and the TA are bypassed
*    (value : NULL or CSI_DD_FLAGS_XFER_BY_MEMORY)
*    (Conv case - value is combinated with CSITPRECVONLY or CSITPSENDONLY)
* CSICHAR48     RunMode
*    Indicates the RunMode of the application used to send a synchronous
*    Request or an asynchronous Message
*/
typedef struct tagLI_MSGCONTEXT {
    CSICHAR4      StrucId;           /* 01 Structure Identifier         */
    CSILONG       Version;           /* 02 Structure Version            */
    CSILONG       EventType;         /* 03 Origin Event Type            */
    CSILONG       ExchangeMode;      /* 04 Synchronous | Asynchronous   */
    CSIIITFHDR   *TraceInfo_P;       /* 05 Trace info structure.        */
    CSIBOOLEAN    isTrcInfoInMsg;    /* 06 Trace info structure.        */
    CSICHAR48     TriggerQName;      /* 07 The queue of arrival(async.) */
    CSIQOS       *QoS_P;             /* 08 Pointer to message QoS       */
    CSICHAR      *UserProfileList_P; /* 09 User Profiles List           */
    CSICHAR      *PrevGatewayList_P; /* 10 Prev. Gateways list          */
    CSICHAR256    OrigGateway;       /* 11 Originator gateway           */
    CSICHAR256    DestGateway;       /* 12 Destination gateway          */
    CSICHAR48     NextHopName;       /* 13 Next local service or queue  */
    CSILONG       SvcFlags;          /* 14 Service flags (sync)         */
    CSIMQMD      *MsgDesc_P;         /* 15 CSI MQ Message Descriptor    */
    CSICHAR32     MsgTypeId;         /* 16 Message Type Identifier      */
    CSILONG       ClientCodePage;    /* 17 Client App. Code Page        */
    CSICHAR128    ClientHostFormat;  /* 18 Client App. Host Format      */
    CSILONG       ServerCodePage;    /* 19 Server App. Code Page        */
    CSICHAR128    ServerHostFormat;  /* 20 Server App. Host Format      */
    CSILONG       Direction;         /* 21 Direction of msg. (Req|Repl) */
    CSILONG       XferMemory;        /* 22 Xfer by memory               */
    CSICHAR48     RunMode;           /* 23 RunMode of application       */
} LI_MSGCONTEXT; 

/*
* @MACRODEF LI_MSGCONTEXT_DEFAULT
* Default (initializer) LI_MSGCONTEXT structure
*/
#define LI_MSGCONTEXT_DEFAULT {LI_MSGCONTEXT_STRUC_ID_ARRAY}, \
                              LI_MSGCONTEXT_VERSION, \
                              0L, \
                              0L, \
                              NULL, \
                              CSITRUE, \
                              {""}, \
                              NULL, \
                              NULL, \
                              NULL, \
                              {""}, \
                              {""}, \
                              {""}, \
                              0L, \
                              NULL, \
                              {""}, \
                              0L, \
                              {""}, \
                              0L, \
                              {""}, \
                              LI_REQUEST, \
                              0, \
                              {""}

/*****************************************************/
/*** LI CONVERSATION CONTEXT STRUCTURE DEFINITIONS ***/
/*****************************************************/
/*
* @TYPE LI_CONVCONTEXT
* (For LI conversational server only) The LI current conversation context.
*
* @FIELD
* CSICHAR4 structId
*    The structure identifier.
*
* CSILONG version
*    The structure version.
*
* CSILONG cd_init
*    The Conversation Descriptor associated with the connection initiator,
*    i.e. the entity that connected first with the LI. This entity may be
*    a RAP/GAS or a conversational Transfer Agent. This conv. descriptor is
*    retrieved in the CSISVCINFO structure, input parameter of the LI service.
*
* CSILONG cd_sub
*    The Conversation Descriptor associated with the subordinate of the
*    connection, i.e. the entity to which the LI "CSI_connect's". 
*    cd_init and cd_sub cannot be equal; the LI manages two different
*    conversations and relays the data from one interlocutor to the other.
*
* CSILONG to
*    The Conversation Descriptor used for the CSI_send in the Conversational
*    Processing routine. It is either cd_init or cd_sub.
*
* CSILONG from
*    The Conversation Descriptor used for the CSI_recv in the Conversational
*    Processing routine. It is either cd_init or cd_sub.
*
*    Note: the couple (from; to) defines the direction of the data transfer and
*          may only have 2 values: either (from = cd_init; to = cd_sub )
*                                  or     (from = cd_sub ; to = cd_init)
*          This underlines the fact that the communication is only half-duplex.
*
* CSILONG seqnum
*    Sequence Number. This parameter is incremented to keep tracks of the
*    data sent in the conversation. For audit purposes.
*
* @SEEALSO
* <@LOCALFUN li_ConvProc>
* <@FUNCTION li_service (conversational)>
*/
typedef struct tagLI_CONVCONTEXT {
    CSICHAR4      structId;
    CSILONG       version;
    CSILONG       cd_init;
    CSILONG       cd_sub;
    CSILONG       to;
    CSILONG       from;
    CSILONG       seqnum;
} LI_CONVCONTEXT;

/*
* @MACRODEF LI_CONVCONTEXT_STRUC_ID
* LI_CONVCONTEXT structure identifier.
*/
#define LI_CONVCONTEXT_STRUC_ID     "LIC"

/*
* @MACRODEF LI_CONVCONTEXT_STRUC_ID_ARRAY
* LI_CONVCONTEXT structure identifier (array form).
*/
#define LI_CONVCONTEXT_STRUC_ID_ARRAY 'L','I','C','\0'

/*
* @MACRODEF LI_CONVCONTEXT_VERSION_1
* LI_CONVCONTEXT structure version.
*/
#define LI_CONVCONTEXT_VERSION_1     1L

/*
* @MACRODEF LI_CONVCONTEXT_DEFAULT
* Default (initialiser) LI_CONVCONTEXT structure.
*/

#define LI_CONVCONTEXT_DEFAULT {LI_CONVCONTEXT_STRUC_ID_ARRAY} \
                               LI_CONVCONTEXT_VERSION_1, \
                               0L, \
                               0L, \
                               0L, \
                               0L, \
                               0L


#endif/*  _LI_PRTYP_H */
/****************************************************************************/
